import React from 'react';
import { ComponentPropsWithMetadata } from '../../../utils/commons';
import { DragProps } from '../../../ui/drag-and-drop';
import { ListItem, MenuVariants } from './types';
export interface CustomMenuProps extends ComponentPropsWithMetadata {
    /**
     * These jsdoc-styled comments will appear on
     * the Storybook's Docs page and in the hints from an IDE.
     *
     * Please, think about whoever will encounter your component for the first time.
     * Take your time to explain why this prop is here, what it does, how it affect your component, etc.
     */
    /** Allows providing a custom class name to the DIV element that surrounds the text */
    className?: string;
    /** List of objects of generic type `T` extending `Item`,
     * `Item = {
        key: string;
        title: string | React.ReactNode;
        disabled?: boolean;
        active?: boolean;
        status?: ItemStatus;
      }`
    */
    items: ListItem[];
    /** Sets clicked item to the active and returns item */
    onClick: (item: ListItem) => void;
    /** See in Additional types  */
    dragProps?: DragProps<ListItem, any>;
    /** Applies anchor menu style */
    variant?: MenuVariants.DEFAULT | MenuVariants.ANCHOR;
}
export declare const CustomMenu: React.ForwardRefExoticComponent<CustomMenuProps & React.RefAttributes<HTMLDivElement>>;
export default CustomMenu;
